==> haskell-crypto-numbers-0.2.7-133-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-crypto-numbers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 crypto-numbers
version:              0.2.7
visibility:           public
id:                   crypto-numbers-0.2.7-HlwZPZGmk5NBl9oVlMij2K
key:                  crypto-numbers-0.2.7-HlwZPZGmk5NBl9oVlMij2K
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
homepage:             https://github.com/vincenthz/hs-crypto-numbers
synopsis:             Cryptographic numbers: functions and algorithms
description:          Cryptographic numbers: functions and algorithms
category:             Cryptography
abi:                  8afef0ba213eb4cd0c580403e4974b84
exposed:              True
exposed-modules:
    Crypto.Number.Basic Crypto.Number.F2m Crypto.Number.Generate
    Crypto.Number.ModArithmetic Crypto.Number.Polynomial
    Crypto.Number.Prime Crypto.Number.Serialize

import-dirs:          /usr/lib/ghc-8.10.1/site-local/crypto-numbers-0.2.7
library-dirs:         /usr/lib/ghc-8.10.1/site-local/crypto-numbers-0.2.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/crypto-numbers-0.2.7
hs-libraries:         HScrypto-numbers-0.2.7-HlwZPZGmk5NBl9oVlMij2K
depends:
    base-4.14.0.0 bytestring-0.10.10.0
    crypto-random-0.0.9-A49qLY7KjvhGTonxabJzsy ghc-prim-0.6.1
    integer-gmp-1.0.3.0 vector-0.12.1.2-CYdo0xBKGbnK8ZGEF4yFOM

haddock-interfaces:
    /usr/share/doc/haskell-crypto-numbers/html/crypto-numbers.haddock

haddock-html:         /usr/share/doc/haskell-crypto-numbers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-crypto-numbers-0.2.7-137-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-crypto-numbers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 crypto-numbers
version:              0.2.7
visibility:           public
id:                   crypto-numbers-0.2.7-4ZZLZ4HoISJEpoVwYywzpJ
key:                  crypto-numbers-0.2.7-4ZZLZ4HoISJEpoVwYywzpJ
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
homepage:             https://github.com/vincenthz/hs-crypto-numbers
synopsis:             Cryptographic numbers: functions and algorithms
description:          Cryptographic numbers: functions and algorithms
category:             Cryptography
abi:                  03119cad89339cde2dca43c1307214a0
exposed:              True
exposed-modules:
    Crypto.Number.Basic Crypto.Number.F2m Crypto.Number.Generate
    Crypto.Number.ModArithmetic Crypto.Number.Polynomial
    Crypto.Number.Prime Crypto.Number.Serialize

import-dirs:          /usr/lib/ghc-8.10.2/site-local/crypto-numbers-0.2.7
library-dirs:         /usr/lib/ghc-8.10.2/site-local/crypto-numbers-0.2.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/crypto-numbers-0.2.7
hs-libraries:         HScrypto-numbers-0.2.7-4ZZLZ4HoISJEpoVwYywzpJ
depends:
    base-4.14.1.0 bytestring-0.10.10.0
    crypto-random-0.0.9-GPxOeTz2E11EnnLzznRPcV ghc-prim-0.6.1
    integer-gmp-1.0.3.0 vector-0.12.1.2-1NVIFdUJ04d5LWJjqOrbRq

haddock-interfaces:
    /usr/share/doc/haskell-crypto-numbers/html/crypto-numbers.haddock

haddock-html:         /usr/share/doc/haskell-crypto-numbers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
